@@ -1,7 +1,7 @@
 __project_name__ = 'upsies'
 __description__ = 'Media metadata aggregator'
 __homepage__ = 'https://upsies.readthedocs.io'
-__version__ = '2021.08.12'
+__version__ = '2021.09.06'
 __author__ = 'plotski'
 __author_email__ = 'plotski@example.org'
 
@@ -22,8 +22,11 @@ def application_shutdown(config):
 
     :param config: :class:`~.configfiles.ConfigFiles` instance
     """
+    import asyncio
+
     from . import utils
-    utils.http.close()
+
+    asyncio.get_event_loop().run_until_complete(utils.http.close())
     utils.fs.limit_directory_size(
         path=config['config']['main']['cache_directory'],
         max_total_size=config['config']['main']['max_cache_size'],
