@@ -226,7 +226,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def release_type_job(self):
         return jobs.dialog.ChoiceJob(
-            name='release-type',
+            name=self.get_job_name('release-type'),
             label='Release Type',
             choices=(
                 ('Movie', release.ReleaseType.movie),
@@ -253,7 +253,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_title_job(self):
         self.imdb_job.signal.register('output', self.fill_in_movie_title)
         return jobs.dialog.TextFieldJob(
-            name='movie-title',
+            name=self.get_job_name('movie-title'),
             label='Title',
             condition=self.make_job_condition('movie_title_job', release.ReleaseType.movie),
             validator=self.movie_title_validator,
@@ -283,7 +283,7 @@ class BbTrackerJobs(TrackerJobsBase):
         else:
             guessed_year = self.release_name.year
         return jobs.dialog.TextFieldJob(
-            name='movie-year',
+            name=self.get_job_name('movie-year'),
             label='Year',
             condition=self.make_job_condition('movie_year_job', release.ReleaseType.movie),
             text=guessed_year,
@@ -309,7 +309,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_resolution_job(self):
         return self.make_choice_job(
-            name='movie-resolution',
+            name=self.get_job_name('movie-resolution'),
             label='Resolution',
             condition=self.make_job_condition('movie_resolution_job', release.ReleaseType.movie),
             autodetected=self.release_info_resolution,
@@ -334,7 +334,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_source_job(self):
         return self.make_choice_job(
-            name='movie-source',
+            name=self.get_job_name('movie-source'),
             label='Source',
             condition=self.make_job_condition('movie_source_job', release.ReleaseType.movie),
             autodetected=self.release_name.source,
@@ -366,7 +366,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_audio_codec_job(self):
         return self.make_choice_job(
-            name='movie-audio-codec',
+            name=self.get_job_name('movie-audio-codec'),
             label='Audio Codec',
             condition=self.make_job_condition('movie_audio_codec_job', release.ReleaseType.movie),
             autodetected=self.release_info_audio_format,
@@ -389,7 +389,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_video_codec_job(self):
         return self.make_choice_job(
-            name='movie-video-codec',
+            name=self.get_job_name('movie-video-codec'),
             label='Video Codec',
             condition=self.make_job_condition('movie_video_codec_job', release.ReleaseType.movie),
             autodetected=self.release_name.video_format,
@@ -413,7 +413,7 @@ class BbTrackerJobs(TrackerJobsBase):
         files = sorted(fs.file_list(self.content_path), key=fs.file_size)
         autodetected_extension = fs.file_extension(files[-1])
         return self.make_choice_job(
-            name='movie-container',
+            name=self.get_job_name('movie-container'),
             label='Container',
             condition=self.make_job_condition('movie_container_job', release.ReleaseType.movie),
             autodetected=autodetected_extension,
@@ -432,7 +432,7 @@ class BbTrackerJobs(TrackerJobsBase):
     @cached_property
     def movie_release_info_job(self):
         return jobs.dialog.TextFieldJob(
-            name='movie-release-info',
+            name=self.get_job_name('movie-release-info'),
             label='Release Info',
             condition=self.make_job_condition('movie_release_info_job', release.ReleaseType.movie),
             text=self.get_movie_release_info(),
@@ -443,7 +443,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_poster_job(self):
         """Re-upload poster from IMDb to :attr:`~.TrackerJobsBase.image_host`"""
         return jobs.custom.CustomJob(
-            name='movie-poster',
+            name=self.get_job_name('movie-poster'),
             label='Poster',
             condition=self.make_job_condition('movie_poster_job', release.ReleaseType.movie),
             worker=self.movie_get_poster_url,
@@ -458,7 +458,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_tags_job(self):
         self.imdb_job.signal.register('output', self.fill_in_movie_tags)
         return jobs.dialog.TextFieldJob(
-            name='movie-tags',
+            name=self.get_job_name('movie-tags'),
             label='Tags',
             condition=self.make_job_condition('movie_tags_job', release.ReleaseType.movie),
             validator=self.movie_tags_validator,
@@ -482,7 +482,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def movie_description_job(self):
         self.imdb_job.signal.register('finished', self.fill_in_movie_description)
         return jobs.dialog.TextFieldJob(
-            name='movie-description',
+            name=self.get_job_name('movie-description'),
             label='Description',
             condition=self.make_job_condition('movie_description_job', release.ReleaseType.movie),
             validator=self.movie_description_validator,
@@ -518,7 +518,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_title_job(self):
         self.tvmaze_job.signal.register('output', self.fill_in_series_title)
         return jobs.dialog.TextFieldJob(
-            name='series-title',
+            name=self.get_job_name('series-title'),
             label='Title',
             condition=self.make_job_condition('series_title_job', release.ReleaseType.season, release.ReleaseType.episode),
             validator=self.series_title_validator,
@@ -547,7 +547,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_poster_job(self):
         """Re-upload poster from TVmaze to :attr:`~.TrackerJobsBase.image_host`"""
         return jobs.custom.CustomJob(
-            name='series-poster',
+            name=self.get_job_name('series-poster'),
             label='Poster',
             condition=self.make_job_condition('series_poster_job', release.ReleaseType.season, release.ReleaseType.episode),
             worker=self.series_get_poster_url,
@@ -562,7 +562,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_tags_job(self):
         self.tvmaze_job.signal.register('output', self.fill_in_series_tags)
         return jobs.dialog.TextFieldJob(
-            name='series-tags',
+            name=self.get_job_name('series-tags'),
             label='Tags',
             condition=self.make_job_condition('series_tags_job', release.ReleaseType.season, release.ReleaseType.episode),
             validator=self.series_tags_validator,
@@ -586,7 +586,7 @@ class BbTrackerJobs(TrackerJobsBase):
     def series_description_job(self):
         self.tvmaze_job.signal.register('finished', self.fill_in_series_description)
         return jobs.dialog.TextFieldJob(
-            name='series-description',
+            name=self.get_job_name('series-description'),
             label='Description',
             condition=self.make_job_condition('series_description_job', release.ReleaseType.season, release.ReleaseType.episode),
             validator=self.series_description_validator,
@@ -610,7 +610,7 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_subtitles(self):
-        subtitle_tracks = video.tracks(self.content_path).get('Text', ())
+        subtitle_tracks = video.tracks(self.content_path, default={}).get('Text', ())
         if subtitle_tracks:
             subtitle_languages = [track.get('Language') for track in subtitle_tracks]
             if 'en' in subtitle_languages:
@@ -638,10 +638,9 @@ class BbTrackerJobs(TrackerJobsBase):
         # Move/TV Rule 3.6.1 - Encodes with a stored resolution less than 700px
         #                      AND a height less than 460px should be labelled
         #                      "SD"
-        width = video.width(self.content_path)
-        height = video.height(self.content_path)
-        _log.debug('WTFSD: width=%r, height=%r', width, height)
-        if 0 < width < 700 and 0 < height < 460:
+        width = video.width(self.content_path, default=0)
+        height = video.height(self.content_path, default=0)
+        if 1 < width < 700 and 1 < height < 460:
             return 'SD'
 
         # Movie Rule 3.6.2 - 576p PAL encodes with a stored resolution of at
@@ -650,7 +649,9 @@ class BbTrackerJobs(TrackerJobsBase):
         #                    Release Info field
         # We also apply this to series releases by using this property in
         # get_series_title_and_release_info().
-        if self.release_name.resolution == '576p' and video.frame_rate(self.content_path) == 25:
+        resolution = self.release_name.resolution
+        frame_rate = video.frame_rate(self.content_path, default=0)
+        if resolution == '576p' and frame_rate == 25:
             return '576p PAL'
 
         return self.release_name.resolution
@@ -673,18 +674,18 @@ class BbTrackerJobs(TrackerJobsBase):
 
     @property
     def release_info_hdr_format(self):
-        hdr_format = video.hdr_format(self.content_path)
+        hdr_format = video.hdr_format(self.content_path, default=None)
         if hdr_format:
             return hdr_format
 
     @property
     def release_info_10bit(self):
-        if video.bit_depth(self.content_path) == '10':
+        if video.bit_depth(self.content_path, default=None) == 10:
             return '10-bit'
 
     @property
     def release_info_dual_audio(self):
-        if video.has_dual_audio(self.content_path):
+        if video.has_dual_audio(self.content_path, default=False):
             return 'Dual Audio'
 
     @property
@@ -932,6 +933,10 @@ class BbTrackerJobs(TrackerJobsBase):
                 )
                 s = re.sub(r'\.+', '.', s)  # Dedup "."
                 s = unidecode.unidecode(s)  # Replace non-ASCII
+                for regex, replacement in self._tags_translation.items():
+                    if regex.search(s):
+                        s = replacement
+                        break
                 normalized.append(s)
             return normalized
 
@@ -965,6 +970,10 @@ class BbTrackerJobs(TrackerJobsBase):
 
         return tags_string
 
+    _tags_translation = {
+        re.compile('^sci.?fi$'): 'science.fiction',
+    }
+
     async def get_description(self):
         info_table = await asyncio.gather(
             self.format_description_webdbs(),
@@ -1085,8 +1094,13 @@ class BbTrackerJobs(TrackerJobsBase):
                     + ', '.join(countries))
 
     async def format_description_runtime(self):
+        def format_runtime(seconds):
+            if seconds > 0:
+                return f'[b]Runtime[/b]: {timestamp.pretty(runtime)}'
+
         if self.is_movie_release or self.is_episode_release:
-            runtime = video.duration(self.content_path)
+            runtime = video.duration(self.content_path, default=0)
+            return format_runtime(runtime)
         elif self.is_season_release:
             # Get all video files
             filepaths = fs.file_list(self.content_path, extensions=constants.VIDEO_FILE_EXTENSIONS)
@@ -1095,11 +1109,11 @@ class BbTrackerJobs(TrackerJobsBase):
                 filepaths = filepaths[1:-1]
             # Get average from 3 episodes
             filepaths = filepaths[:3]
-            durations = [video.duration(f) for f in filepaths]
+            durations = [video.duration(f, default=0) for f in filepaths]
             runtime = sum(durations) / len(durations)
+            return format_runtime(runtime)
         else:
             return None
-        return f'[b]Runtime[/b]: {timestamp.pretty(runtime)}'
 
     @staticmethod
     def _format_person(person):
