@@ -2,13 +2,12 @@
 Concrete :class:`~.base.TrackerBase` subclass for bB
 """
 
-import argparse
 import asyncio
 import re
 import urllib
 
 from ... import errors
-from ...utils import html, http
+from ...utils import argtypes, html, http
 from ..base import TrackerBase
 from .config import BbTrackerConfig
 from .jobs import BbTrackerJobs
@@ -17,15 +16,6 @@ import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
 
-def number_of_screenshots(value):
-    try:
-        return type(BbTrackerConfig.defaults['screenshots'])(value)
-    except ValueError as e:
-        # Raising ArgumentTypeError preserves the error message while raising
-        # ValueError produces a generic "invalid value" error message.
-        raise argparse.ArgumentTypeError(e)
-
-
 class BbTracker(TrackerBase):
     name = 'bb'
     label = 'bB'
@@ -38,9 +28,11 @@ class BbTracker(TrackerBase):
         ('--poster-file',): {
             'help': 'Path or URL to poster image',
         },
-        ('--screenshots', '-s'): {
-            'help': 'How many screenshots to make',
-            'type': number_of_screenshots,
+        ('--screenshots', '--ss'): {
+            'help': ('How many screenshots to make '
+                     f'(min={BbTrackerConfig.defaults["screenshots"].min}, '
+                     f'max={BbTrackerConfig.defaults["screenshots"].max})'),
+            'type': argtypes.number_of_screenshots(BbTrackerConfig),
         },
         ('--title', '-t'): {
             'group': 'single-job',
@@ -79,8 +71,9 @@ class BbTracker(TrackerBase):
         'torrent': '/torrents.php',
     }
 
-    _max_login_attempts = 15
+    _max_login_attempts = 30
     _login_retry_delay = 1
+    _login_retry_delay_max = 5
 
     async def login(self):
         if not self.is_logged_in:
@@ -128,7 +121,8 @@ class BbTracker(TrackerBase):
 
             if self._login_attempts < self._max_login_attempts:
                 if self._login_attempts:
-                    self._login_retry_delay = min(self._login_retry_delay * 1.2, 10)
+                    self._login_retry_delay = min(self._login_retry_delay * 1.2,
+                                                  self._login_retry_delay_max)
                 assert type(self)._login_retry_delay == 1
                 if self._login_attempts > 1:
                     _log.debug(f'Encountered login bug; retrying in {round(self._login_retry_delay)}s')
