@@ -6,8 +6,8 @@ import io
 import os
 import re
 
-from ... import jobs
-from ...utils import as_groups, cached_property, release
+from ... import __homepage__, __project_name__, jobs
+from ...utils import as_groups, cached_property, release, string
 from ..base import TrackerJobsBase
 
 import logging  # isort:skip
@@ -17,8 +17,10 @@ _log = logging.getLogger(__name__)
 class BhdTrackerJobs(TrackerJobsBase):
     release_name_translation = {
         'audio_format': {
-            re.compile(r'^AC-3$'): r'DD',
-            re.compile(r'^E-AC-3$'): r'DD+',
+            # Don't match against end of string to preserve extensions like
+            # "Atmos"
+            re.compile(r'^AC-3'): r'DD',
+            re.compile(r'^E-AC-3'): r'DDP',
         },
     }
 
@@ -36,6 +38,12 @@ class BhdTrackerJobs(TrackerJobsBase):
                 job.condition = self.make_job_condition(job_attr)
 
         return (
+            # Background jobs
+            self.create_torrent_job,
+            self.mediainfo_job,
+            self.screenshots_job,
+            self.upload_screenshots_job,
+
             # Interactive jobs
             self.imdb_job,
             self.tmdb_job,
@@ -46,12 +54,6 @@ class BhdTrackerJobs(TrackerJobsBase):
             self.description_job,
             self.scene_check_job,
             self.tags_job,
-
-            # Background jobs
-            self.create_torrent_job,
-            self.mediainfo_job,
-            self.screenshots_job,
-            self.upload_screenshots_job,
         )
 
     def make_job_condition(self, job_attr):
@@ -75,7 +77,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
         self.release_name_job.signal.register('output', self.autodetect_category)
         return self.make_choice_job(
-            name='category',
+            name=self.get_job_name('category'),
             label='Category',
             condition=self.make_job_condition('category_job'),
             options=(
@@ -109,7 +111,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
         self.release_name_job.signal.register('output', self.autodetect_type)
         return self.make_choice_job(
-            name='type',
+            name=self.get_job_name('type'),
             label='Type',
             condition=self.make_job_condition('type_job'),
             autofinish=False,
@@ -170,7 +172,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
         self.release_name_job.signal.register('output', self.autodetect_source)
         return self.make_choice_job(
-            name='source',
+            name=self.get_job_name('source'),
             label='Source',
             condition=self.make_job_condition('source_job'),
             options=(
@@ -209,7 +211,7 @@ class BhdTrackerJobs(TrackerJobsBase):
     @cached_property
     def description_job(self):
         job = jobs.dialog.TextFieldJob(
-            name='description',
+            name=self.get_job_name('description'),
             label='Description',
             condition=self.make_job_condition('description_job'),
             read_only=True,
@@ -217,7 +219,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         )
         job.add_task(
             job.fetch_text(
-                coro=self.generate_screenshots_bbcode(),
+                coro=self.generate_description(),
                 finish_on_success=True,
             )
         )
@@ -232,30 +234,34 @@ class BhdTrackerJobs(TrackerJobsBase):
     :class:`~.imghosts.ImageHostBase` subclass
     """
 
-    async def generate_screenshots_bbcode(self):
+    async def generate_description(self):
         # Wait until all screenshots are uploaded
         await self.upload_screenshots_job.wait()
         rows = []
         screenshot_groups = as_groups(
             self.upload_screenshots_job.uploaded_images,
             group_sizes=(2,),
-            default='PLACEHOLDER',
+            default=None,
         )
         for screenshots in screenshot_groups:
             cells = []
             for screenshot in screenshots:
-                if screenshot != 'PLACEHOLDER':
+                if screenshot is not None:
                     cells.append(f'[url={screenshot}][img]{screenshot.thumbnail_url}[/img][/url]')
             # Space between columns
             rows.append(' '.join(cells))
-        # Empty line between rows
-        bbcode = '\n\n'.join(rows)
-        return f'[center]\n{bbcode}\n[/center]'
+        screenshots = '[center]\n' + '\n\n'.join(rows) + '\n[/center]'
+        promotion = (
+            '[right][size=1]'
+            f'Shared with [url={__homepage__}]{__project_name__}[/url]'
+            '[/size][/right]'
+        )
+        return screenshots + '\n\n' + promotion
 
     @cached_property
     def tags_job(self):
         job = jobs.dialog.TextFieldJob(
-            name='tags',
+            name=self.get_job_name('tags'),
             label='Tags',
             condition=self.make_job_condition('tags_job'),
             read_only=True,
@@ -391,8 +397,8 @@ class BhdTrackerJobs(TrackerJobsBase):
                     # Limit size to 500kB
                     if os.path.getsize(nfo_path) <= self.max_nfo_size:
                         try:
-                            with open(nfo_path, 'r') as f:
-                                return f.read()
+                            with open(nfo_path, 'rb') as f:
+                                return string.autodecode(f.read())
                         except OSError as e:
                             self.error(e.strerror if e.strerror else str(e))
 
