@@ -13,6 +13,7 @@ class submit(CommandBase):
 
     argument_definitions = {}
 
+    subcommand_name = 'TRACKER'
     subcommands = {
         tracker.name: {
             # Default arguments for all tackers
@@ -65,14 +66,7 @@ class submit(CommandBase):
         CLI arguments where CLI arguments take precedence unless their value is
         `None`
         """
-        config = self.config['trackers'][self.tracker_name]
-        cli_args = vars(self.args)
-        options = {}
-        options.update(config)
-        for k, v in cli_args.items():
-            if v is not None:
-                options[k] = v
-        return options
+        return self.get_options('trackers', self.tracker_name)
 
     @utils.cached_property
     def tracker(self):
@@ -109,11 +103,11 @@ class submit(CommandBase):
         imghost_name = self.tracker_options.get('image_host', None)
         if imghost_name:
             # Apply tracker-specific image host configuration
-            imghost_config = self.config['imghosts'][imghost_name].copy()
-            imghost_config.update(self.tracker.TrackerJobs.image_host_config.get(imghost_name, {}))
+            options = self.config['imghosts'][imghost_name].copy()
+            options.update(self.tracker.TrackerJobs.image_host_config.get(imghost_name, {}))
             return utils.imghosts.imghost(
                 name=imghost_name,
-                config=imghost_config,
+                options=options,
             )
 
     def _get_btclient(self):
