@@ -8,6 +8,7 @@ import hashlib
 import io
 import json
 import os
+import time
 
 import httpx
 
@@ -17,6 +18,7 @@ from . import fs, html
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
 
+_default_timeout = 60
 _default_headers = {
     'Accept-Language': 'en-US,en;q=0.5',
     'User-Agent': f'{__project_name__}/{__version__}',
@@ -26,10 +28,23 @@ _default_headers = {
 # requests concurrently without bugging the server.
 _request_locks = collections.defaultdict(lambda: asyncio.Lock())
 
+# A global client session seems to be the only way to get cookies working
+# reliably. The downside is that we have to remember to close the client before
+# the application terminates.
 _client = httpx.AsyncClient(
-    timeout=60,
+    timeout=_default_timeout,
+    headers=_default_headers,
 )
 
+async def close():
+    """
+    Close the global client session used for all requests
+
+    This coroutine function must be called before the application terminates.
+    """
+    _log.debug('Closing client: %r', _client)
+    await _client.aclose()
+    _log.debug('Closed client: %r', _client)
 
 cache_directory = None
 """
@@ -39,15 +54,10 @@ If this is set to a falsy value, default to :attr:`~.constants.CACHE_DIRPATH`.
 """
 
 
-def close():
-    """Close the client session"""
-    _log.debug('Closing client: %r', _client)
-    asyncio.get_event_loop().run_until_complete(_client.aclose())
-    _log.debug('Closed client: %r', _client)
-
-
 async def get(url, headers={}, params={}, auth=None,
-              cache=False, user_agent=False, allow_redirects=True):
+              cache=False, max_cache_age=float('inf'),
+              user_agent=False, allow_redirects=True,
+              timeout=_default_timeout):
     """
     Perform HTTP GET request
 
@@ -57,8 +67,10 @@ async def get(url, headers={}, params={}, auth=None,
     :param auth: Basic access authentication; sequence of <username> and
         <password> or `None`
     :param bool cache: Whether to use cached response if available
+    :param int,float max_cache_age: Maximum age of cache in seconds
     :param bool user_agent: Whether to send the User-Agent header
     :param bool allow_redirects: Whether to follow redirects
+    :param int,float timeout: Maximum number of seconds the request may take
 
     :return: Response text
     :rtype: Response
@@ -71,12 +83,16 @@ async def get(url, headers={}, params={}, auth=None,
         params=params,
         auth=auth,
         cache=cache,
+        max_cache_age=max_cache_age,
         user_agent=user_agent,
         allow_redirects=allow_redirects,
+        timeout=timeout,
     )
 
 async def post(url, headers={}, data={}, files={}, auth=None,
-               cache=False, user_agent=False, allow_redirects=True):
+               cache=False, max_cache_age=float('inf'),
+               user_agent=False, allow_redirects=True,
+               timeout=_default_timeout):
     """
     Perform HTTP POST request
 
@@ -118,8 +134,10 @@ async def post(url, headers={}, data={}, files={}, auth=None,
     :param auth: Basic access authentication; sequence of <username> and
         <password> or `None`
     :param bool cache: Whether to use cached response if available
+    :param int,float max_cache_age: Maximum age of cache in seconds
     :param bool user_agent: Whether to send the User-Agent header
     :param bool allow_redirects: Whether to follow redirects
+    :param int,float timeout: Maximum number of seconds the request may take
 
     :return: Response text
     :rtype: Response
@@ -133,8 +151,10 @@ async def post(url, headers={}, data={}, files={}, auth=None,
         files=files,
         auth=auth,
         cache=cache,
+        max_cache_age=max_cache_age,
         user_agent=user_agent,
         allow_redirects=allow_redirects,
+        timeout=timeout,
     )
 
 async def download(url, filepath, *args, **kwargs):
@@ -219,25 +239,26 @@ class Result(str):
 
 
 async def _request(method, url, headers={}, params={}, data={}, files={},
-                   allow_redirects=True, cache=False, auth=None, user_agent=False):
+                   allow_redirects=True, cache=False, max_cache_age=float('inf'),
+                   auth=None, user_agent=False, timeout=_default_timeout):
     if method.upper() not in ('GET', 'POST'):
         raise ValueError(f'Invalid method: {method}')
 
+    # Create request object
     if isinstance(data, (bytes, str)):
         build_request_args = {'content': data}
     else:
         build_request_args = {'data': data}
-
-    headers = {**_default_headers, **headers}
     request = _client.build_request(
         method=str(method),
-        headers=headers,
         url=str(url),
+        headers={**_default_headers, **headers},
         params=params,
         files=_open_files(files),
         **build_request_args,
     )
 
+    # Adjust User-Agent
     if isinstance(user_agent, str):
         request.headers['User-Agent'] = user_agent
     elif not user_agent:
@@ -250,7 +271,7 @@ async def _request(method, url, headers={}, params={}, data={}, files={},
     async with request_lock:
         if cache:
             cache_file = _cache_file(method, url, params)
-            result = _from_cache(cache_file)
+            result = _from_cache(cache_file, max_age=max_cache_age)
             if result is not None:
                 return result
 
@@ -258,6 +279,7 @@ async def _request(method, url, headers={}, params={}, data={}, files={},
         try:
             response = await _client.send(
                 request=request,
+                timeout=timeout,
                 auth=auth,
                 allow_redirects=allow_redirects,
             )
@@ -349,11 +371,18 @@ def _to_cache(cache_file, bytes):
         raise RuntimeError(f'Unable to write cache file {cache_file}: {e}')
 
 
-def _from_cache(cache_file):
-    bytes = _read_bytes_from_file(cache_file)
-    text = _read_string_from_file(cache_file)
-    if bytes and text:
-        return Result(text=text, bytes=bytes)
+def _from_cache(cache_file, max_age=float('inf')):
+    try:
+        cache_mtime = os.stat(cache_file).st_mtime
+    except FileNotFoundError:
+        return None
+    else:
+        cache_age = time.time() - cache_mtime
+        if cache_age <= max_age:
+            bytes = _read_bytes_from_file(cache_file)
+            text = _read_string_from_file(cache_file)
+            if bytes and text:
+                return Result(text=text, bytes=bytes)
 
 
 def _read_string_from_file(filepath):
