@@ -137,13 +137,6 @@ class ReleaseName(collections.abc.Mapping):
         """
         self._info = ReleaseInfo(str(path))
 
-    def _tracks(self):
-        # Ignore non-existing files and other file system issues
-        try:
-            return video.tracks(self._path)
-        except errors.ContentError:
-            return {}
-
     def __repr__(self):
         posargs = [self._path]
         kwargs = {}
@@ -349,19 +342,26 @@ class ReleaseName(collections.abc.Mapping):
 
     @_translated_property
     def edition(self):
-        """List of "Director's Cut", "Uncut", "Unrated", etc"""
+        """
+        List of "Director's Cut", "Uncut", "Unrated", etc
+
+        :raise ContentError: if path exists but contains unexpected data
+        """
         if 'edition' not in self._info:
             self._info['edition'] = []
 
         # Dual Audio
-        if 'Dual Audio' not in self._info['edition']:
-            if self.has_dual_audio:
-                self._info['edition'].append('Dual Audio')
+        while 'Dual Audio' in self._info['edition']:
+            self._info['edition'].remove('Dual Audio')
+        if self.has_dual_audio:
+            self._info['edition'].append('Dual Audio')
 
         # HDR format (e.g. "Dolby Vision" or "HDR10")
-        if not any(hdr in self._info['edition'] for hdr in video.hdr_formats):
-            if self.hdr_format:
-                self._info['edition'].append(self.hdr_format)
+        for hdr_format in video.hdr_formats:
+            while hdr_format in self._info['edition']:
+                self._info['edition'].remove(hdr_format)
+        if self.hdr_format:
+            self._info['edition'].append(self.hdr_format)
 
         return self._info['edition']
 
@@ -380,8 +380,12 @@ class ReleaseName(collections.abc.Mapping):
 
     @_translated_property
     def resolution(self):
-        '''Resolution (e.g. "1080p") or "UNKNOWN_RESOLUTION"'''
-        res = video.resolution(self._path)
+        """
+        Resolution (e.g. "1080p") or "UNKNOWN_RESOLUTION"
+
+        :raise ContentError: if path exists but contains unexpected data
+        """
+        res = video.resolution(self._path, default=None)
         if res is None:
             res = self._info.get('resolution') or 'UNKNOWN_RESOLUTION'
         return res
@@ -392,8 +396,12 @@ class ReleaseName(collections.abc.Mapping):
 
     @_translated_property
     def audio_format(self):
-        '''Audio format or "UNKNOWN_AUDIO_FORMAT"'''
-        af = video.audio_format(self._path)
+        """
+        Audio format or "UNKNOWN_AUDIO_FORMAT"
+
+        :raise ContentError: if path exists but contains unexpected data
+        """
+        af = video.audio_format(self._path, default=None)
         if af is None:
             af = self._info.get('audio_codec') or 'UNKNOWN_AUDIO_FORMAT'
         return af
@@ -404,8 +412,12 @@ class ReleaseName(collections.abc.Mapping):
 
     @_translated_property
     def audio_channels(self):
-        """Audio channels (e.g. "5.1") or empty string"""
-        ac = video.audio_channels(self._path)
+        """
+        Audio channels (e.g. "5.1") or empty string
+
+        :raise ContentError: if path exists but contains unexpected data
+        """
+        ac = video.audio_channels(self._path, default=None)
         if ac is None:
             ac = self._info.get('audio_channels') or ''
         return ac
@@ -416,8 +428,12 @@ class ReleaseName(collections.abc.Mapping):
 
     @_translated_property
     def video_format(self):
-        '''Video format (or encoder in case of x264/x265/XviD) or "UNKNOWN_VIDEO_FORMAT"'''
-        vf = video.video_format(self._path)
+        """
+        Video format (or encoder in case of x264/x265/XviD) or "UNKNOWN_VIDEO_FORMAT"
+
+        :raise ContentError: if path exists but contains unexpected data
+        """
+        vf = video.video_format(self._path, default=None)
         if vf is None:
             vf = self._info.get('video_codec') or 'UNKNOWN_VIDEO_FORMAT'
         return vf
@@ -449,6 +465,8 @@ class ReleaseName(collections.abc.Mapping):
 
         Setting this value back to `None` turns on autodetection as described
         above.
+
+        :raise ContentError: if path exists but contains unexpected data
         """
         # Use manually set value unless it is None
         if getattr(self, '_has_commentary', None) is not None:
@@ -481,6 +499,8 @@ class ReleaseName(collections.abc.Mapping):
 
         Setting this value back to `None` turns on autodetection as described
         above.
+
+        :raise ContentError: if path exists but contains unexpected data
         """
         # Use manually set value unless it is None
         if getattr(self, '_has_dual_audio', None) is not None:
@@ -505,7 +525,7 @@ class ReleaseName(collections.abc.Mapping):
     @_translated_property
     def hdr_format(self):
         """
-        HDR format name (e.g. "Dolby Vision" or "HDR10")
+        HDR format name (e.g. "Dolby Vision" or "HDR10") or `None`
 
         If not set explicitly and the given `path` exists, this value is
         autodetected if possible, otherwise default to whatever
@@ -513,6 +533,8 @@ class ReleaseName(collections.abc.Mapping):
 
         Setting this value back to `None` turns on autodetection as described
         above.
+
+        :raise ContentError: if path exists but contains unexpected data
         """
         # Use manually set value unless it is None
         if getattr(self, '_hdr_format', None) is not None:
@@ -520,8 +542,8 @@ class ReleaseName(collections.abc.Mapping):
 
         # Autodetect
         if os.path.exists(self._path):
-            hdr_format = video.hdr_format(self._path)
-            if hdr_format:
+            hdr_format = video.hdr_format(self._path, default=None)
+            if hdr_format is not None:
                 self._hdr_format = hdr_format
                 return self._hdr_format
 
